PyRuster
========

Simple features
---------------

Implementing some syntax like rust:

- Option
- Result

Requirements
------------
``python: 3.6``

Installation
------------

.. code-block:: text

    pip install pyruster

Usage
-----
You can find detailed instructions in the `pyruster README <https://github.com/elling19/pyruster/blob/main/README.MD>`_.
